==> haskell-genvalidity-property-1.0.0.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-C8ZjU6WOgmb3mNys8CcZll
key:                  genvalidity-property-1.0.0.0-C8ZjU6WOgmb3mNys8CcZll
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  1e47e2f4b86a868004b9740dffda82e3
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.0.2/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-C8ZjU6WOgmb3mNys8CcZll
depends:
    QuickCheck-2.14.2-50g6nvTiNE5CM6werdwjjj base-4.15.1.0
    genvalidity-1.0.0.1-Ii7ulnaiDQo5PP2mFmlNsW
    hspec-2.9.7-7Az7A2chKoRCZSD8kYe0xn
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    validity-0.12.0.1-FccxWRVejHA5n7X7GIhSp4

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-1.0.0.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-DBxWPOEZ9GE8MB91eh5Dki
key:                  genvalidity-property-1.0.0.0-DBxWPOEZ9GE8MB91eh5Dki
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  2809815119035e364bc0c49d87ff9232
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.0.2/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-DBxWPOEZ9GE8MB91eh5Dki
depends:
    QuickCheck-2.14.2-CWXi9Q1t8724ceglmst3lc base-4.15.1.0
    genvalidity-1.1.0.0-2VVV08CXccYBIiqsOIpCYG
    hspec-2.10.3-AHzuRt4LQT74nJ5Y9lLHCy
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    validity-0.12.0.1-9GdAnRudLk6UJBd2eCJsc

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
